@@ -31,7 +31,7 @@ sub new {
     my $self = bless {
         listens              => $args{listens} || [],
         host                 => $args{host} || 0,
-        port                 => $args{port} || 8080,
+        port                 => $args{port} || $args{socket} || 8080,
         timeout              => $args{timeout} || 300,
         keepalive_timeout    => $args{keepalive_timeout} || 2,
         max_keepalive_reqs   => $args{max_keepalive_reqs} || 1,
@@ -72,14 +72,21 @@ sub run {
 sub setup_listener {
     my $self = shift;
     if (scalar(grep {defined $_} @{$self->{listens}}) == 0) {
-        my $sock =
-            IO::Socket::INET->new(
+        my $sock;
+        if ($self->{port} =~ /^[0-9]+$/s) {
+            $sock = IO::Socket::INET->new(
                 Listen    => SOMAXCONN,
                 LocalPort => $self->{port},
                 LocalAddr => $self->{host},
                 Proto     => 'tcp',
                 ReuseAddr => 1,
             ) or die "failed to listen to port $self->{port}:$!";
+        } else {
+            $sock = IO::Socket::UNIX->new(
+                Listen => SOMAXCONN,
+                Local  => $self->{port},
+            ) or die "failed to listen to socket $self->{port}:$!";
+        }
         $self->{listens}[fileno($sock)] = {
             host => $self->{host},
             port => $self->{port},
@@ -408,33 +415,30 @@ sub _handle_response {
 
     # try to set content-length when keepalive can be used, or disable it
     my $use_chunked;
-    if ( $protocol eq 'HTTP/1.0' ) {
-        if ($$use_keepalive_r) {
-            if (defined $send_headers{'content-length'}
-                || defined $send_headers{'transfer-encoding'}) {
-                # ok
-            }
-            elsif ( ! Plack::Util::status_with_no_entity_body($status_code)
-                    && defined(my $cl = Plack::Util::content_length($body))) {
-                push @lines, "Content-Length: $cl\015\012";
-            }
-            else {
-                $$use_keepalive_r = undef
-            }            
-        }
-        push @lines, "Connection: keep-alive\015\012" if $$use_keepalive_r;
-        push @lines, "Connection: close\015\012" if !$$use_keepalive_r; #fmm..
-    }
-    elsif ( $protocol eq 'HTTP/1.1' ) {
+    if (defined($protocol) && $protocol eq 'HTTP/1.1') {
         if (defined $send_headers{'content-length'}
                 || defined $send_headers{'transfer-encoding'}) {
             # ok
-        } elsif ( !Plack::Util::status_with_no_entity_body($status_code) ) {
+        } elsif (!Plack::Util::status_with_no_entity_body($status_code)) {
             push @lines, "Transfer-Encoding: chunked\015\012";
             $use_chunked = 1;
         }
         push @lines, "Connection: close\015\012" unless $$use_keepalive_r;
-
+    } else {
+        # HTTP/1.0
+        if ($$use_keepalive_r) {
+            if (defined $send_headers{'content-length'}
+                || defined $send_headers{'transfer-encoding'}) {
+                # ok
+            } elsif (!Plack::Util::status_with_no_entity_body($status_code)
+                     && defined(my $cl = Plack::Util::content_length($body))) {
+                push @lines, "Content-Length: $cl\015\012";
+            } else {
+                $$use_keepalive_r = undef;
+            }
+        }
+        push @lines, "Connection: keep-alive\015\012" if $$use_keepalive_r;
+        push @lines, "Connection: close\015\012" if !$$use_keepalive_r; #fmm..
     }
 
     unshift @lines, "HTTP/1.1 $status_code @{[ HTTP::Status::status_message($status_code) ]}\015\012";
